package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`MP`!````"!\```````!``````````&`!`0``
M`````````$``.``(`$``%@`5``8````$````0`````````!``````````$``
M````````P`$```````#``0````````@``````````P````0``````@``````
M```"``````````(````````:`````````!H``````````0`````````!````
M!0```````````````````````````````````.2/````````Y(\`````````
M``$```````$````&````F/L```````"8^P$``````)C[`0``````X`0`````
M```X!0```````````0```````@````8```"H^P```````*C[`0``````J/L!
M``````#@`0```````.`!````````"`````````!0Y71D!````/B)````````
M^(D```````#XB0```````/0`````````]``````````$`````````%'E=&0&
M`````````````````````````````````````````````````````````!``
M````````4N5T9`0```"8^P```````)C[`0``````F/L!``````!H!```````
M`&@$`````````0`````````O;&EB+VQD+6UU<VPM86%R8V@V-"YS;RXQ````
M`````!$```!+````!`````@````A$!``!<`$@"@`$`6`AD"$@B$`!`D`!(F(
M@!A!N@0""$L```!,````4````%4```!6````70```%X```!?`````````&$`
M``!B`````````&,```!D````9P```````````````:\TZ&I_FGSJT^\.SMY'
M+6_%WQ\NQ9NVN(WQ#M1DU'QV5#R4(?_D#MEQ6!SZH6Q@PN4_++(!BV]"^M>'
MXD?&`5COEWF[XY)\5<,\TF>OS&:(!W#30T75[#-BV^T5C"7,?ZF<F^"G`@IJ
M&IY0O]I7&Z/@^TD``````````````````````````````````````P`'`'@9
M`````````````````````````P`2`````@`````````````````!````$@``
M```````````````````````)````$0````````````````````````#<`0``
M$0````````````````````````!E`0``$@`````````````````````````0
M````$@````````````````````````"U`0``$@``````````````````````
M```8````$@`````````````````````````?````$@``````````````````
M``````#I`0``$@````````````````````````#!`0``$@``````````````
M```````````H````(`````````````````````````#L`@``(0``````````
M``````````````!`````$@````````````````````````!&````$@``````
M``````````````````!-````$@````````````````````````"C`@``$@``
M``````````````````````#!`@``$@````````````````````````!4````
M$@`````````````````````````$`@``$@````````````````````````!;
M````$@````````````````````````"*`@``$@``````````````````````
M``!B````$@````````````````````````!J````$@``````````````````
M``````"<`@``$@````````````````````````!R````$@``````````````
M``````````!S`@``$@````````````````````````!Z````$@``````````
M``````````````"`````$@````````````````````````")````(```````
M``````````````````"S`@``$@````````````````````````"E````$@``
M``````````````````````"J````$@````````````````````````""`0``
M%@````````````````````````"1`@``$@`````````````````````````Q
M`@``$@````````````````````````"Q````$@``````````````````````
M```C`@``$@`````````````````````````R`P``$@``````````````````
M``````#K`@``$0````````````````````````!5`@``$@``````````````
M``````````#8`@``$@````````````````````````#M`@``$0``````````
M``````````````"X````$@````````````````````````#!````$0``````
M``````````````````!S`0``$@````````````````````````#3````(@``
M``````````````````````#B````(`````````````````````````#X````
M$@````````````````````````#0`@``$@````````````````````````!!
M`@``$@````````````````````````#]````$@``````````````````````
M```#`0``(`````````````````````````!^`@``$@``````````````````
M```````=`0``$@````````````````````````"F`0``$@``````````````
M```````````B`0``$@````````````````````````!C`@``$@``````````
M``````````````"5`0``$@`````````````````````````H`0``$@``````
M```````````````````Y`0``$@````````````````````````#_`0``$@``
M``````````````````````![````$@`````````````````````````0`@``
M$@````````````````````````!*`@``$@````````````````````````"Z
M`@``$@````````````````````````"K`@``$@``````````````````````
M```_`0``$@````````````````````````#Z`0``$@``````````````````
M``````!&`0``$@````````````````````````!-`0``$@``````````````
M``````````#J`@``(0````````````````````````!>`0``$@``````````
M```````````````R!```$``3`-```@````````````````#E`@``$@`)`&`=
M````````J`$```````#6`0``$@`*`#Q)````````!`````````!T`P``$@`)
M`-`L````````%`8```````!"!```$@`)`,`T````````9`````````!1`P``
M$@`)`$@G````````!`````````#F`P``$@`'`'@9````````!`````````"7
M`P``$@`)`.0R````````W`$```````#L`P``$``3`'@``@``````````````
M```:!```$@`)`$PG````````Y`$```````#/`P``$``3`'@``@``````````
M``````!B`P``$@`)`!PL````````M`````````"!`P``$@`)`)@E````````
M+`````````")`P``$@`)`*0K````````6`````````"M`P``$@`)`$1&````
M````9`$```````#"`P``$@`)`#`I````````,`````````#;`P``$``3`-``
M`@`````````````````]!```$``3`-```@`````````````````7`P``$@`)
M`"0?````````*`````````#Z`P``$@`)`&`I````````'`$```````"X`P``
M$0`2`'```@``````"``````````3!```$``2`'@``@````````````````#4
M`P``$@`)``@?``````````````````#C`P``$@`)`.A%````````7```````
M```@`P``$@`)`/PK````````(``````````[`P``$@`)`!0F````````-`$`
M```````G!```$@`)`*A'````````E`$````````Q!```$``3`-```@``````
M```````````&!```$@`)`'PJ````````*`$`````````;W!E;F1I<@!S=&1E
M<G(`<F5A;&QO8P!A8V-E<W,`<VYP<FEN=&8`7U]D97)E9VES=&5R7V9R86UE
M7VEN9F\`;'-E96L`9V5T<&ED`'-T<F-M<`!M96US970`=6YL:6YK`&UE;6UO
M=F4`<W1R;F-M<`!S=')R8VAR`&QS=&%T`&-L;W-E9&ER`%])5$U?9&5R96=I
M<W1E<E1-0VQO;F5486)L90!O<&5N`'-T<G-T<@!S=')C:'(`<F5A9&QI;FL`
M7U]S=&%C:U]C:&M?9W5A<F0`7U]C>&%?9FEN86QI>F4`7U]R96=I<W1E<E]F
M<F%M95]I;F9O`&5X:70`8VQO<V4`7TE435]R96=I<W1E<E1-0VQO;F5486)L
M90!R96%D`')M9&ER`%]?97)R;F]?;&]C871I;VX`;6MD:7(`;65M8W!Y`'-T
M<FQE;@!?7W-T86-K7V-H:U]F86EL`&=E='5I9`!097)L7W-Y<U]T97)M`%!E
M<FQ?<WES7VEN:70S`%!,7V-U<G)E;G1?8V]N=&5X=`!097)L7V%T9F]R:U]L
M;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C
M;VYT97AT`%]F:6YI`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S`'!E
M<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S
M=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]N97=84P!P
M97)L7V1E<W1R=6-T`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?
M<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`'-T<F-P>0!R96%D9&ER`'-P<FEN
M=&8`<W1R9'5P`'-T<G1O:P!P=&AR96%D7V%T9F]R:P!F<')I;G1F`%]?;&EB
M8U]S=&%R=%]M86EN`%]?7V5N=FER;VX`;&EB<&5R;"YS;P!L:6)C+FUU<VPM
M86%R8V@V-"YS;RXQ`%]S=&%R=%]C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W
M=6ED`'!A<E]C=7)R96YT7V5X96-?<')O8P!P87)?8W5R<F5N=%]E>&5C`'!A
M<E]S971U<%]L:6)P871H`'!A<E]M:W1M<&1I<@!X<U]I;FET`'!A<E]E;G9?
M8VQE86X`6%-?26YT97)N86QS7U!!4E]"3T]4`'-H85]U<&1A=&4`;7E?<&%R
M7W!L`'!A<E]B87-E;F%M90!?7V)S<U]S=&%R=`!?7V5N9%]?`'-H85]I;FET
M`%]?8G-S7W-T87)T7U\`<&%R7V1I<FYA;64`<&%R7VEN:71?96YV`%]E9&%T
M80!P87)?9FEN9'!R;V<`<VAA7V9I;F%L`%]?8G-S7V5N9%]?`%]E;F0`<&%R
M7V-L96%N=7``+W5S<B]L:6(O<&5R;#4O8V]R95]P97)L+T-/4D4``````)C[
M`0```````P0````````@(````````*#[`0```````P0```````#`'P``````
M`(#_`0```````P0```````!@'0```````)C_`0```````P0````````\20``
M`````+#_`0```````P0```````!X&0```````````@```````P0`````````
M``(``````!```@```````P0```````#R2P```````!@``@```````P0`````
M``!-20```````"@``@```````P0````````N2@```````#```@```````P0`
M```````G2@```````#@``@```````P0```````#F2P```````$```@``````
M`P0```````!$2@```````$@``@```````P0```````#N2P```````%@``@``
M`````P0```````#82P```````&```@```````P0```````#=2P```````'``
M`@```````P0```````#W2P```````(C_`0```````00```0`````````````
M`)#_`0```````00```4``````````````*#_`0```````00```T`````````
M`````*C_`0```````00``!\``````````````+C_`0``````!@0``",`````
M`````````,#_`0```````00``"P``````````````,C_`0```````00``"X`
M`````````````-#_`0```````00``#```````````````-C_`0```````00`
M`#$``````````````.#_`0```````00``#8``````````````.C_`0``````
M`00``#L``````````````/#_`0```````00``#P``````````````/C_`0``
M`````00``$$``````````````*#]`0```````@0```,``````````````*C]
M`0```````@0```8``````````````+#]`0```````@0```<`````````````
M`+C]`0```````@0```@``````````````,#]`0```````@0```D`````````
M`````,C]`0```````@0```H``````````````-#]`0```````@0```L`````
M`````````-C]`0```````@0```P``````````````.#]`0```````@0```T`
M`````````````.C]`0```````@0```\``````````````/#]`0```````@0`
M`!```````````````/C]`0```````@0``!$```````````````#^`0``````
M`@0``!(```````````````C^`0```````@0``!,``````````````!#^`0``
M`````@0``!0``````````````!C^`0```````@0``!4``````````````"#^
M`0```````@0``!8``````````````"C^`0```````@0``!<`````````````
M`##^`0```````@0``!@``````````````#C^`0```````@0``!D`````````
M`````$#^`0```````@0``!H``````````````$C^`0```````@0``!L`````
M`````````%#^`0```````@0``!P``````````````%C^`0```````@0``!T`
M`````````````&#^`0```````@0``!X``````````````&C^`0```````@0`
M`"```````````````'#^`0```````@0``"$``````````````'C^`0``````
M`@0``"(``````````````(#^`0```````@0``"0``````````````(C^`0``
M`````@0``"4``````````````)#^`0```````@0``"8``````````````)C^
M`0```````@0``"<``````````````*#^`0```````@0``"@`````````````
M`*C^`0```````@0``"H``````````````+#^`0```````@0``"L`````````
M`````+C^`0```````@0``"T``````````````,#^`0```````@0``"\`````
M`````````,C^`0```````@0``#```````````````-#^`0```````@0``#$`
M`````````````-C^`0```````@0``#(``````````````.#^`0```````@0`
M`#,``````````````.C^`0```````@0``#0``````````````/#^`0``````
M`@0``#4``````````````/C^`0```````@0``#<```````````````#_`0``
M`````@0``#@```````````````C_`0```````@0``#D``````````````!#_
M`0```````@0``#H``````````````!C_`0```````@0``#T`````````````
M`"#_`0```````@0``#X``````````````"C_`0```````@0``#\`````````
M`````##_`0```````@0``$```````````````#C_`0```````@0``$(`````
M`````````$#_`0```````@0``$,``````````````$C_`0```````@0``$0`
M`````````````%#_`0```````@0``$4``````````````%C_`0```````@0`
M`$8``````````````&#_`0```````@0``$<``````````````&C_`0``````
M`@0``$@``````````````'#_`0```````@0``$H``````````````/U[OZG]
M`P"1_7O!J,`#7]8``````````/![OZGP``#0$<Y&^1!B-I$@`A_6'R`#U1\@
M`]4?(`/5\```T!'21OD0@C:1(`(?UO```-`1UD;Y$*(VD2`"'];P``#0$=I&
M^1#"-I$@`A_6\```T!'>1OD0XC:1(`(?UO```-`1XD;Y$`(WD2`"'];P``#0
M$>9&^1`B-Y$@`A_6\```T!'J1OD00C>1(`(?UO```-`1[D;Y$&(WD2`"'];P
M``#0$?)&^1""-Y$@`A_6\```T!'V1OD0HC>1(`(?UO```-`1^D;Y$,(WD2`"
M'];P``#0$?Y&^1#B-Y$@`A_6\```T!$"1_D0`CB1(`(?UO```-`1!D?Y$"(X
MD2`"'];P``#0$0I'^1!".)$@`A_6\```T!$.1_D08CB1(`(?UO```-`1$D?Y
M$((XD2`"'];P``#0$19'^1"B.)$@`A_6\```T!$:1_D0PCB1(`(?UO```-`1
M'D?Y$.(XD2`"'];P``#0$2)'^1`".9$@`A_6\```T!$F1_D0(CF1(`(?UO``
M`-`1*D?Y$$(YD2`"'];P``#0$2Y'^1!B.9$@`A_6\```T!$R1_D0@CF1(`(?
MUO```-`1-D?Y$*(YD2`"'];P``#0$3I'^1#".9$@`A_6\```T!$^1_D0XCF1
M(`(?UO```-`10D?Y$`(ZD2`"'];P``#0$49'^1`B.I$@`A_6\```T!%*1_D0
M0CJ1(`(?UO```-`13D?Y$&(ZD2`"'];P``#0$5)'^1"".I$@`A_6\```T!%6
M1_D0HCJ1(`(?UO```-`16D?Y$,(ZD2`"'];P``#0$5Y'^1#B.I$@`A_6\```
MT!%B1_D0`CN1(`(?UO```-`19D?Y$"([D2`"'];P``#0$6I'^1!".Y$@`A_6
M\```T!%N1_D08CN1(`(?UO```-`1<D?Y$(([D2`"'];P``#0$79'^1"B.Y$@
M`A_6\```T!%Z1_D0PCN1(`(?UO```-`1?D?Y$.([D2`"'];P``#0$8)'^1`"
M/)$@`A_6\```T!&&1_D0(CR1(`(?UO```-`1BD?Y$$(\D2`"'];P``#0$8Y'
M^1!B/)$@`A_6\```T!&21_D0@CR1(`(?UO```-`1ED?Y$*(\D2`"'];P``#0
M$9I'^1#"/)$@`A_6\```T!&>1_D0XCR1(`(?UO```-`1HD?Y$`(]D2`"'];P
M``#0$:9'^1`B/9$@`A_6\```T!&J1_D00CV1(`(?UO```-`1KD?Y$&(]D2`"
M'];P``#0$;)'^1""/9$@`A_6\```T!&V1_D0HCV1(`(?UO```-`1ND?Y$,(]
MD2`"'];]>[NI_0,`D?-3`:GS``#P]```T)3>1_GU$P#Y5=`[U>*'`ZGBXP"1
MX0,!D>!/`+G@,P&1E___E^(``-!"_$?YX```T`#X1_GA`P*J-?__E^```-``
MR$?Y``!`.4`!`#5L__^78L("D4`,`/E@``"U(`"`4I/__Y>J__^7H&IT^!_<
M*#FA:G3X("A2.0`$`#(@*!(YX$]`N10,`!$`$``1`'Q]DY?__Y?B(T#YXP,`
MJF#"`I'D3T"Y`P0`^4``0/E@``#Y````\`!(+Y%@!`#YX```\``X0/E@"`#Y
M````\`!4+Y%@#`#Y``"`T@$0`!$`!`"1(7Q]DY\``&L,!0!4=<("D7]H(?CB
M`Q0J!`"`T@$``+`A$!>1H`Y`^27__Y?T`P`J@```-:`.0/EM__^7]`,`*G7"
M`I&@#D#Y2?__EP```/``A">1F@``E&`!`+6@"D#YH```M0```/``6":1E```
ME*`*`/E@P@*1``A`^4```+1[!0"4<\("D6`.0/F0__^7M_[_E_430/G@`Q0J
M\U-!J?U[Q:C``U_617A@^&5H(?C2__\7'0"`TAX`@-+@`P"1X0``T"&@+I$?
M['R2`0``%.(#`*H%`(#2Y```T(3,1_E!A$#XXP``T&/81_G@``#0`,!'^2+_
M_Q<?(`/5X```\`#@`9'A``#P(>`!D3\``.O```!4X0``T"'41_EA``"T\`,!
MJ@`"'];``U_6X```\`#@`9'A``#P(>`!D2$``,LB_'_300R!BR'\09/!``"T
MX@``T$+P1_EB``"T\`,"J@`"'];``U_6'R`#U?U[OJG]`P"1\PL`^?,``/!@
MXD$Y``(`->```-``Z$?Y@```M.```/```$#Y!?__E]C__Y?@``#0`-!'^8``
M`+0@``#0`,`KD8K^_Y<@`(!28.(!.?,+0/G]>\*HP`-?UN```+``[$?Y0`$`
MM/U[OZGA``#0(```T/T#`)$A``*1`,`KD?/^_Y?]>\&HS?__%\S__Q?]>[RI
M_0,`D?-3`:GU6P*I]V,#J0`%`+3V`P"JX```L`#@1_D7`$#Y=P0`M/@#`:KB
M`Q:J0`!`.1_T`'$$&$!Z(0,`5$(`%DOU`Q>J4WQ`D[0"0/G4`0"TX@,3JN$#
M%JK@`Q2JBO[_ER`"`#6`:G,X'_0`<<$!`%2U`A?+<P8`D90"$XNU_D.3%0,`
MN?5;0JG@`Q2J\U-!J?=C0ZG]>\2HP`-?UD($`)'C__\7M2(`D>C__Q<4`(#2
M]?__%^$``+`AY$?Y_7N^J?T#`)$B`$#YX@\`^0(`@-+A4P"1R?__E^$``+`A
MY$?YXP]`^2(`0/EC``+K`@"`TD```%3\_O^7_7O"J,`#7];]>[RI_0,`D?-3
M`:GS`P"J]-,`D>```+``Y$?Y]1,`^?4``+"UXD?Y`0!`^>$?`/D!`(#2X0,4
MJN`#$ZJO__^7(`$`M>```+``Y$?YXA]`^0$`0/E"``'K`0"`TD`!`%3A_O^7
MH`)`^>(W@+D"#`*+0`1`^4```/G@_?^T0B``D?S__Q?S4T&I]1-`^?U[Q*C`
M`U_6_7NUJ>$``+`AY$?Y_0,`D?,+`/GS`P"J(@!`^>)7`/D"`(#2X:,`D4+^
M_Y>``@`UX3M`N0(`E%(A#!02/Q!`<2000GK!``!4X`,3JD$`@%+L_?^7'P``
M<>`7GQKA``"P(>1'^>-70/DB`$#Y8P`"ZP(`@-*```!4MO[_EP``@%+W__\7
M\PM`^?U[RZC``U_6_7NSJ>$``+`AY$?Y_0,`D?-3`:GU6P*I]V,#J2(`0/GB
M9P#Y`@"`TF`"`+0!`$`Y]`,`J@$"`#2^_?^7]@,`JJ`!`+07``#0&```T/<V
M)9$8,R61X`,6JN;]_Y?S`P"JH`$`M>`#%JH2_O^7X`,4JFC^_Y?@``"P`.1'
M^>)G0/D!`$#Y0@`!ZP$`@-)@!0!4C/[_EW-.`)'A`Q>JX`,3JM#]_Y>`_?\T
MX0,8JN`#$ZK,_?^7`/W_-.`#%*I]_O^7]0,`JN`#$ZIZ_O^7M0(`"[4*`!&@
M?D"3VOW_E^,#$ZKB`Q2J]0,`J@$``-`A/"619/[_E^$C`9'@`Q6J5?[_EQ\$
M`#%``0!4X%M`N0`,%!(?$$!QP0``5.`#%:JY__^7X`,5JD?^_Y?+__\7X`,5
MJL#]_Y?[__\7\U-!J?5;0JGW8T.I_7O-J,`#7];]>[JI_0,`D?-3`:GS`P&J
M]`,`JN```+``Y$?Y]5L"J?=C`ZGY(P#Y`0!`^>$O`/D!`(#28`)`.1_T`'%!
M``!4<P8`D>`#$ZI'_O^7X5,!D?4#`*K@`Q2J#/__E_8#`*H@`@"T0/[_E[\"
M`.NH!`!4`0"`TF!J83C`:B$X(00`D:#__S7@``"P`.1'^>(O0/D!`$#Y0@`!
MZP$`@-+`"`!4-?[_E_<``+#WXD?Y``"`TOD"0/DB(P#1]@,`J@`$`)%!>&#X
MH?__M>$``-#`"@`1(K!`N0!\?9-B!0`TX0,`JN`#&:I(_?^7X`(`^<#\_[3@
M`D#YP08`$?97`+D?V"'XX`,4J@$`0#D_]`!Q)!A`>N$$`%3W``"P]^)'^0``
M%,OV5X"YM0H`D:#"((OX`D#YUO)]TW#]_Y<`:S;X0/K_M.`"0/D`:';XX@,`
MJH$60#@`!`"1`?`?.&$``#0_]`!Q0?__5*$'@%)!```Y`0"`TF)J83@":"$X
M(00`D:+__S7!__\7(@"`4B*P`+E:_?^7^`,`JH#W_[3"?GV3X0,9JEG]_Y?X
M`@#YTO__%P`$`)'5__\7\U-!J?5;0JGW8T.I^2-`^?U[QJC``U_6X```L`#<
M1_E$T#O5X@``L$+T1_DC``#0`0``T&.P)Y&`:&#X(50ED<C]_Q?]>[ZI_0,`
MD?-3`:E3T#O5]```L)3>1_E@:G3X[O__EV!J=/@$``#0\U-!J81$+Y']>\*H
MXP,$J@4`@%("``"P`0``T$*0"Y$AQ"61`/W_%PP*A-+_8RS+X```L`#D1_G]
M>P"I_0,`D?-3`:GTXP"1]1,`^0$`0/GA)Q#Y`0"`T@/]_Y?C`P`J!```T`(`
M`-"$&":10B@FD>`#%*HA`(+2Y_S_EQ\$`#%!`0!4`P"`TN```+``Y$?YXB=0
M^0$`0/E"``'K`0"`T@`%`%2L_?^7`'Q`DQ\$0/%)``!4`'T@U``(@M+S8R"+
MX0,3JN`#%*H"`(+22OW_E_0#`*J`_?\W``0`$0!\0)/]_/^7XP,`JN#\_[25
M?D"3'P`3ZX(``%0``!6+?P(`ZZ/]_U1_`!/KB0``5&`"%8M_``#K`_W_5"``
M@E*?`@!KK/S_5.`#`ZKB`Q6JX0,3JGW]_Y?C`P"J'V@U.-/__Q?]>T"IX`,#
MJO-30:D,"H32]1-`^?]C+(O``U_6L___%PP<@M+_8RS+_7L`J?T#`)'S4P&I
M]`,`JO,#`:K@``"P`.1'^?5;`JGW8P.I^6L$J0$`0/GA;PCY`0"`T@```-``
M6":18/[_E_8#`*KA!8!2X`,4JOS\_Y>@`0"T````T.$#%*H`?":1!O__E^``
M`+``Y$?YXF](^0$`0/E"``'K`0"`TN`)`%1;_?^7X`,3JMG\_Y<8``#0%P``
MT`&S)I$9``#00/W_E_<V)9'S`P"J.;LFD?5C`Y$S_?^T8`)`.1\``'%S$I>:
MM@``M.$#$ZK@`Q:JD/S_EZ`&`#3@`Q.J0?W_EP$$`-%A`@&+?P(!ZX(``%0@
M`$`Y'[P`<<`"`%3@`Q.J./W_E_H#`*K@`Q2J-?W_EUH#`(M:!P"17_\_\>CY
M_U3E`Q2JY`,9JN,#$ZK@`Q6J`@``T`$`@M)"_"F17?S_EP`$`!$?!$!QB0``
M5`!](-0_]!\XY?__%^%C`9'@`Q6J"/W_ER`"`#7@:T"Y``P4$A\@0'&A`0!4
MX`,5JB$`@%)(_/^7(`$`->$#%:H```#0`'PFD;K^_Y?@`Q6JE?S_E_0#`*JQ
M__\7`;,FD0``@-+\_/^7\P,`JK___Q?]>T"IX`,4JO-30:D,'(+2]5M"J?=C
M0ZGY:T2I_V,LB\`#7];]>[ZIX06`4OT#`)'S"P#Y\P,`JF_\_Y=```"T$P0`
MD>`#$ZKS"T#Y_7O"J'G\_Q<,!H+2_V,LR^$``+`AY$?Y_7L`J?T#`)'S4P&I
M(@!`^>(7"/D"`(#2@```M`$`0#GT`P"J(0$`->```+``Y$?YXA=(^0$`0/E"
M``'K`0"`TD`%`%3C_/^7WOS_EP`$`)$?!$#QB`4`5.$#%*KSHP"1X`,3JD?\
M_Y?@`Q.JU?S_EP`$`-%@`@"+'P`3ZXD``%0!`$`Y/[P`<<`"`%3@`Q.JX06`
M4C_\_Y>`_/^T'P`3ZTD``%0?```YX`,3JDG\_Y?A``"P(>1'^>,72/DB`$#Y
M8P`"ZP(`@-+A^_]4_7M`J0P&@M+S4T&I_V,LB\`#7]8?]!\XY?__%_U[0*D,
M!H+2\U-!J0```-#_8RR+`#0ED33\_Q<``(#2ZO__%_U[O:D```#0`,`FD?T#
M`)'S4P&I%```T!,``-#U6P*IL/W_EP```-``Y":1K?W_EP```-``!">1JOW_
MEQ8``-````#0`"@GD:;]_Y=SWB>1@$8GD:/]_Y<```#0`(0GD:#]_Y<5``#0
MP%HFD9W]_Y>@MB>1F_W_E^`#$ZJ9_?^7````T``$*)&6_?^7````T`!\)I&3
M_?^7````T``L*)%]_?^7@```M.$#`*K@`Q.J*/[_EP```-``<"B1=OW_E^$#
M`*J```"T````T`"X*)$@_O^7````T`#D*)%N_?^7X0,`JD`!`+3`6B:1&?[_
ME_5;0JF`1B>1\U-!J0$``-#]>\.H(6@ID1+^_Q<```#0`"0ID6#]_Y?A`P"J
MH/[_M*"V)Y'R__\7_7N^J?T#`)'S"P#Y\P``T&`*0+D?!``Q00$`5````-``
MM">14OW_ET`!`+0``$`Y``$`-!_``''@!Y\:8`H`N6`*0+GS"T#Y_7O"J,`#
M7]8``(!2^O__%_U[OZG]`P"14_S_E^K[_Y=```"T``!`^?U[P:C``U_6_7N]
MJ?T#`)'U6P*I%0``T+9R*9'S4P&I\P,`JN`#%JHU_?^7@```M`$`0#GT`P"J
MX0``->$#$ZJ@<BF1\U-!J?5;0JG]>\.HVOW_%^$#$ZJ]^_^7@`(`M>`#$ZHN
M_/^7]0,`JN`#%*HK_/^7H`(`BP`(`)&,^_^7Y`,4JO4#`*KB`Q.J`P``T`$`
M`-!CL":1(?PID13\_Y?A`Q6JX`,6JN?__Q?S4T&I]5M"J?U[PZC``U_6##*0
MTO]C+,OA(T"1_7L`J?T#`)'S4P&I]`,`JN```+``Y$?Y]5L"J?9#`I'W8P.I
M%0``T/EK!*G[*P#Y`@!`^2+$`/D"`(#2X```T``@`)$!#$#YX3L`^0&``)$"
MC$"IX@\&J2`$0*T"#$6IXH\'J<`&`*T@",`]`#!`^>!'`/F@6B:1X"^`/>[\
M_Y<``P"T`0!`.?,#`*JA`@`TK/__E^```+``Y$?YXB-`D4/$0/D!`$#Y8P`!
MZP$`@-)```!4[/O_E_U[0*G@`Q.J\U-!J0PRD-+U6T*I]V-#J?EK1*G[*T#Y
M_V,LBV+[_Q>0__^7\P,`J@`"`+7WXP&1X`)`^8```+43``#0<[(ID0H``!3,
M_/^78```M?<B`)'X__\7`0!`.:'__S12^_^7\P,`JD#__[3@`Q.JROO_EP#X
M?],9``#0``0`D3G/*9$I^_^7^`,`JO<#`*IB`D`Y@@D`-=,"0/F3`0"TX`,3
MJK7\_Y?S`P"J@`D`M`$`0#E!"0`TZ/S_EP`)`#3@`Q.J.?O_E_,#`*KV@P&1
MLP``M=<"0/EW"0"TX`)`.2`(`#7@`Q.JK/O_E_<#`*K@`QBJJ?O_E_<"``OW
M$A`1&0``T/=^0)/@`Q>J!_O_E^4#&*HCNR:1X@,3J@0``-"$X"F1]@,`J@$`
M`-`A]"F1COO_E^`#%JH!.(!2=_O_EQ\$`#%!!@!4</O_EP0`0+F?1`!QP`4`
M5.```+``Q$?Y`0``T(("0/GC`Q:J``!`^2$8*I%)^_^7$P"`TN```+``Y$?Y
MXB-`D4/$0/D!`$#Y8P`!ZP$`@-(!\_]4_7M`J>`#$ZKS4T&I##*0TO5;0JGW
M8T.I^6M$J?LK0/G_8RR+P`-?UN`#%ZKA`QFJ<P8`D?<*`)%E^_^7KO__%]8B
M`)&N__\7X`,7JM8B`)&;_/^7(/?_-.`#%ZKL^O^7\P,`JK3__Q<3`(#2M___
M%^$#`Y'@`Q:JW?K_E_H#`"J@```UX--`N0`,%!(?$$!Q0`$`5.```+``Q$?Y
MXP,6JH("0/D!``#0``!`^2$$*Y$3^_^7RO__%_/;0+E8^_^7?P(`:X'^_U3@
MTT"Y`"``$A\`!W$!_O]4X`,7JJSZ_Y?S`P"J````L`"<*9$\_/^7X0,`JD`+
M`+67`D#YX`,7JC_[_Y?X`P"J'PP`<6T#`%0`?$"3`0``L``0`-$A4"R1X`(`
MBX+Z_Y>``@`U'Q,`<:```%08%P!1X,IX.!^\`''!`0!4E`9`^90!`+3@`Q2J
M*_O_EQ\,`/$)`0!4`!``T0$``+"``@"+(60LD7#Z_Y<?``!Q]Q*4FK[^_Y?`
M#``UX`,7J@$`@%*E^O^7]`,`*B`,`#1"`(!2(0*`DO<C!I%;^O^7X0,7JN`#
M%"K"`(#2X_K_E^`C1CG`!0`UX"=&.1\,`7%A!0!4X"M&.1\$`7$!!0!4X"]&
M.1\,`7&A!`!4X#-&.1\@`7%!!`!4X#=&.1\4`7'A`P!40@"`4B$'@)+@`Q0J
M0OK_E^$#%ZK@`Q0J(@6`TLKZ_Y<%``"PY`,7JJ5$+Y$!``"P([LFD>(#%JHA
M>"R1X`,3JN7Z_Y?@`Q:JT_K_E^$#$ZJ@6B:1D_S_E^`#$ZJE_O^78O__%X`"
M0/EN_?^7]P,`JJ#T_[6C__\7`@"`4@$`@-+@`Q0J)/K_EPT%`)3X`P"J`@"0
MTN$#%ZK@`Q0JJOK_E^(#`*H?``!Q+`,`5.`#%"KW8P61G/K_E_L#%ZKA`QBJ
M&```L!C/*9$4`(#2^@,%D>`#&JIJ!0"40FMT..`#%ZKA`QBJE`8`D?<*`)&Z
M^O^7GU(`\2'__U0%``"PY`,;JJ5$+Y'_`P8YR?__%^$#%ZK@`QBJ`04`E-[_
M_Q<!``"P````L"%H*9$`M">1%P``L/?N+)%;_/^7.;LFD?KY_Y<4``"PE$8O
MD>0#`"KE`Q2JXP,9JN(#%JK@`Q.J`0``L"&T+)&<^O^7X`,3J@$X@%*%^O^7
M'P0`,6'V_U1^^O^7``!`N1]$`''A]?]4YOG_EUH'`!'D`P`JY@,4JN4#&BKC
M`QFJX@,6JN$#%ZK@`Q.JB?K_E^W__Q?]>[RI_0,`D?-3`:E4T#O5\P``D'/>
M1_GU6P*I]QL`^8!J<_@!P$(Y`<0".0```+``1">1?OO_E\```+0!`$`Y/\0`
M<6$``%0`!$`Y0```--+]_Y>`:G/X8P"`4B(`@%(!``"P(3`MD0WZ_Y?U`P"J
MH`$`M``(0/D"``"P0C@MD0$`0/F`:G/X#?K_EZ`*0/D!`$#Y(`Q`N6``L#:`
M:G/XQ_G_EX!J<_AC`(!2(@"`4@$``+#U``"P(4PMD?CY_Y?W`P"JH`(`M```
M`+``?":15_O_E^(#`*K```"TX`I`^0$`0/F`:G/X]?G_EPL``!20_/^7]@,`
MJN`*0/DV!`"T`0!`^>(#%JJ`:G/X[/G_E^`#%JHR^O^7EFIS^"(`@%(!``"P
M(50MD>`#%JIT^?^7`@``L.$#`*I"J"V1X`,6JM_Y_Y>`:G/XL\("D1_$`CD`
M``"P`%@FD37[_Y=@"@#Y@`$`M6`&0/DA_O^78`H`^0`!`+4```"P`,`MD7#Y
M_Y>AP@*1(01`^2(`0/G5__\7M<("D0$X@%*@"D#Y#/K_E^,#`"H`!``1'P0`
M<62(47K```!4H(I`J0$`0/D```"P`$0ND5[Y_Y?S4T&I]5M"J?<;0/G]>\2H
MP`-?UOU[OJG]`P"1\U,!J?,#`*HD_?^7%_W_E_0#`*JR_?^7P`$`-+,!`+1@
M`D`Y8`$`-`$``+#@`Q2J(>`ID9GY_Y>?`@#KH0``5.`#$ZKS4T&I_7O"J%O[
M_Q?S4T&I_7O"J,`#7];_@PK1!>``D>$``)`AY$?Y!^`!D?U[`*G]`P"1(@!`
M^>)/`?D"`(#2XF,`D>8#`JJA`$"YQD``D:2$0/@A",!:P0`?^('\8-,C'`A3
M(=QXTR$<<))A``&J@_QHTV,<>))DX$2J(0`$JL&`'_C_``7K`?[_5`,(@%)$
M`$#Y8P0`<4$(0/E"(`"111Q`^2$`!,I$,$#YA``%RB$`!,HD_%_3@00!JB%\
M0))!/`#Y8?[_5`0<0*DI,X_2!1A!J4E0J_(($$#Y@?Q;T^/\0M,A%`2J8W@'
MJL(`!<IM?$"20@`'BJH!!<I"``;*2@$$BD%`(8M*`07*X@]`^4H!!HOK%T#Y
M0@`)BR$``HOB$T#Y(0`("VL!"8M"``F+2@$"BR+\6]-"%`&J2@$""X+\0M-"
M>`2J8P`"RDQ\0))C``&*8P`-RF,`!8MC``N+2_U;TVL5"JIC``L+*_Q"TV%Y
M`:I"``'**WQ`DD(`"HI"``S*0@`-B^T;0/FM`0F+0@`-BVW\6].M%0.J0@`-
M"TW]0M.J>0JJ(0`*RDU]0)(A``.*(0`+RB$`#(OL'T#YC`$)BR$`#(M,_%O3
MC!4"JB$`#`ML_$+3@WD#JDH!`\IL?$"22@$"BDH!#<I*`0N+ZR-`^6L!"8M*
M`0N+*_Q;TVL5`:I*`0L+2_Q"TV)Y`JIC``+*2WQ`DF,``8IC``S*8P`-B^TG
M0/FM`0F+8P`-BTW]6].M%0JJ8P`-"RW\0M.A>0&J0@`!RBY\0))"``J*0@`+
MRD(`#(OL*T#YC`$)BT(`#(ML_%O3C!4#JD(`#`M,_4+3BGD*JB$`"LI-?4"2
M(0`#BB$`#LHA``N+ZR]`^6L!"8LA``N+2_Q;TVL5`JHA``L+:_Q"TV-Y`ZI+
M`0/*;'Q`DNHS0/EK`0**:P$-RDH!"8MK`0Z+:P$*BRK\6]-*%0&J:P$*"TK\
M0M-">0*J8P`"RDI\0))C``&*8P`,RF,`#8OM-T#YK0$)BV,`#8MM_5O3K14+
MJF,`#0LM_$+3H7D!JD(``<HM?$"20@`+BD(`"LI"``R+[#M`^8P!"8M"``R+
M;/Q;TXP5`ZI"``P+;/U"TXMY"ZHA``O*;'U`DB$``XHA``W*(0`*B^H_0/E*
M`0F+(0`*BTK\6]-*%0*J(0`*"VK\0M-*>0.J8P$*RDY]0)+K0T#Y8P`"BF,`
M#,IK`0F+8P`-BV,`"XLK_%O3:Q4!JF,`"PM+_$+3:WD"JD(!"\IM?4"2ZD=`
M^4(``8I"``[*2@$)BT(`#(M"``J+:OQ;TTH5`ZI"``H+*OQ"TTIY`:IA`0K*
M3'U`DNM+0/DA``.*(0`-RFL!"8LA``Z+(0`+BTO\6]-K%0*J(0`+"VO\0M-C
M>0.J2@$#RFM\0))*`0**2@$,RDH!#8OM3T#YK0$)BTH!#8LM_%O3K14!JDH!
M#0M-_$+3HGD"JF,``LI-?$"28P`!BF,`"\IC``R+[%-`^8P!"8MC``R+3/U;
MTXP5"JIC``P++/Q"TX%Y`:I"``'*;_Q;TT(`"HKO%0.J0@`-RBQ\0))"``N+
MZU=`^6L!"8M"``N+4$`OB^\!`@M"_4+32G@*JN[]6]/B6T#Y(0`*RB$``XK.
M%0^J(0`,RD(`"8LA``V+;?Q"TZUY`ZHA``*+XE]`^4L!#<HQ0"Z+:P$02LX!
M`0LA=)W2(=NM\FL!#(M"``&+Z?U"TREY#ZIK`0*+POU;TZ,!"<I"%`ZJ8P`1
M2G!!(HM"``L+:T`JB^-C0/E,_%O3C!4"JF,``8MK`0.+P_U"TV]!+(MC>`ZJ
MC`$+"RH!`\KK9T#Y2@$02DI!+8MK`0&+2@$+BXO]6]-K%0RJ3D$KBVL!"@M*
M_$+30GD"JFH``LI*`0]*24$IB^IK0/E*`0&+*0$*BVK]6]-*%0NJ+4$JBTH!
M"0N)_4+3+'D,JDD`#,HI`0Y*(T$CB^EO0/DI`0&+8P`)BTG]6],I%0JJ;D`I
MBRD!`PMC_4+3:W@+JH,!"\IC``U*8D`BB^-S0/EC``&+0@`#BR/]6]-C%`FJ
M34`CBV,``@M"_4+32G@*JF(!"LI"``Y*3$`LB^)W0/E"``&+C`$"BV+\6]-"
M%`.JCD$BBT(`#`LL_4+3B7D)JDP!"<J,`0U*BT$KB^Q[0/F,`0&+:P$,BTS\
M6].,%0*J;4$LBXP!"PMK_$+38WD#JBL!`\IK`0Y*:D$JB^M_0/EK`0&+2@$+
MBXO]6]-K%0RJ3D$KBVL!"@M*_$+30GD"JFH``LI*`0U*24$IB^J#0/E*`0&+
M*0$*BVK]6]-*%0NJ+4$JBTH!"0N)_4+3+'D,JDD`#,HI`0Y*(T$CB^F'0/DI
M`0&+8P`)BTG]6],I%0JJ;D`IBRD!`PMC_4+3:W@+JH,!"\IC``U*8D`BB^.+
M0/EC``&+0@`#BR/]6]-C%`FJ34`CBV,``@M"_4+32G@*JF(!"LI"``Y*3$`L
MB^*/0/E"``&+C`$"BV+\6]-"%`.JCD$BBT(`#`LL_4+3B7D)JDP!"<J,`0U*
MBT$KB^R30/F,`0&+:P$,BTS\6].,%0*J;4$LBXP!"PMK_$+38WD#JBL!`\IK
M`0Y*:D$JB^N70/EK`0&+2@$+BXO]6]-K%0RJ3T$KBVL!"@M*_$+30GD"JFH`
M`LI*`0U*24$IB^J;0/E*`0&+*0$*BVK]6]-*%0NJ30$)"RY!*HN)_4+3+'D,
MJJK]6]-)``S*2A4-JBD!#THC02.+Z9]`^2D!`8MC``F+;T`JBTH!`PMC_4+3
M:W@+JDG]6].#`0O**14*JF,`#DIB0"*+XZ-`^6,``8M"``.+3D`IBRD!`@NB
M_4+337@-JF(!#<I"``]*0T`LB^*G0/GLKT#Y0@`!BV,``HLB_5O30A0)JF,`
M`@M"_4+32G@*JJ(!"LI"``Y*0D`KB^NK0/EA`0&+0@`!BV'\6],A%`.J0@`!
M"R']0M,I>`FJ2P$)JB$!"@IK`0.*:P$!JF%!+8N+FY?2:^.Q\HP!"XLA``R+
M3/Q;TXP5`JHA``P+;/Q"TX-Y`ZHL`0.J;0`)"HP!`HJ,`0VJBD$JB^RS0/F,
M`0N+2@$,BRS\6].,%0&J2@$,"TS\0M.">0*J;``"JDT``PJ,`0&*C`$-JHE!
M*8OLMT#YC`$+BRD!#(M,_5O3C!4*JBD!#`LL_$+3@7D!JDP``:HM``(*C`$*
MBHP!#:J#02.+[+M`^8P!"XMC``R++/U;TXP5":IC``P+3/U"TXIY"JHL``JJ
M30$!"HP!"8J,`0VJ@D$BB^R_0/F,`0N+0@`,BVS\6].,%0.J0@`,"RS]0M.)
M>0FJ3`$)JBT!"@J,`0.*C`$-JH%!(8OLPT#YC`$+BR$`#(M,_%O3C!4"JB$`
M#`ML_$+3@WD#JBP!`ZIM``D*C`$"BHP!#:J*02J+[,=`^8P!"XM*`0R++/Q;
MTXP5`:I*`0P+3/Q"TX)Y`JIL``*J30`#"HP!`8J,`0VJB4$IB^S+0/F,`0N+
M*0$,BTS]6].,%0JJ*0$,"RS\0M.!>0&J3``!JBT``@J,`0J*C`$-JH-!(XOL
MST#YC`$+BV,`#(LL_5O3C!4)JF,`#`M,_4+3BGD*JBP`"JI-`0$*C`$)BHP!
M#:J"02*+[--`^8P!"XM"``R+;/Q;TXP5`ZI"``P++/U"TXEY":I,`0FJ+0$*
M"HP!`XJ,`0VJ@4$AB^S70/F,`0N+(0`,BTS\6].,%0*J(0`,"VS\0M.#>0.J
M+`$#JFT`"0J,`0**C`$-JHI!*HOLVT#YC`$+BTH!#(LL_%O3C!4!JDH!#`M,
M_$+3@GD"JFP``JI-``,*C`$!BHP!#:J)02F+[-]`^8P!"XLI`0R+3/U;TXP5
M"JHI`0P++/Q"TX%Y`:I,``&J+0`""HP!"HJ,`0VJ@T$CB^SC0/F,`0N+8P`,
MBRS]6].,%0FJ8P`,"TS]0M.*>0JJ+``*JDT!`0J,`0F*C`$-JH)!(HOLYT#Y
MC`$+BT(`#(ML_%O3C!4#JD(`#`LL_4+3B7D)JDP!":HM`0H*C`$#BHP!#:J!
M02&+[.M`^8P!"XLA``R+3/Q;TXP5`JHA``P+;/Q"TX-Y`ZHL`0.J;0`)"HP!
M`HJ,`0VJBD$JB^SO0/F,`0N+2@$,BRS\6].,%0&J2@$,"TS\0M.">0*J;``"
MJDT``PJ,`0&*C`$-JHE!*8OL\T#YC`$+BRD!#(M,_5O3C!4*JBD!#`LL_$+3
MC7D!JDP`#:JA`0(*C`$*BHP!`:KA]T#Y@T$CBRS]6],A``N+C!4)JF,``8M!
M_4+3*G@*JH\!`PMP0"R+HP$*JD$!#0IC``F*8P`!JN'[0/EB0"*+X_U;TV,4
M#ZHA``N+0@`!BR']0M-N``(+*W@)JE%`(XM!`0O*XO]`^2$`$$K,_5O3PSJ8
MTD-,N?*,%0ZJ0@`#BR%`+8LA``*+B0$!"S!`+(OA_4+3(G@/JBS]6]-A`0+*
MC!4)JB$`$4HA0"J+Z@-!^4H!`XLA``J+ROU"TTIY#JHM0"R+@0$!"TP`"LJ,
M`1!*BT$KB^P'0?F,`0.+:P$,BRS\6].,%0&J;D$LBXP!"PLK_4+3:7D)JDL!
M"<IK`0U*8D$BB^L+0?EK`0.+0@`+BXO]6]-K%0RJ34`KBVL!`@LB_$+307@!
MJB(!`<I"``Y*2D`JB^(/0?E"``.+2@$"BV+]6]-"%`NJ3D$BBT(`"@N*_4+3
M3'D,JBH`#,I*`0U*24$IB^H30?E*`0.+*0$*BTK\6]-*%0*J+4$JBTH!"0MI
M_4+3*WD+JHD!"\HI`0Y*(4$AB^D70?DI`0.+(0`)BTG]6],I%0JJ+D`IBRD!
M`0M!_$+3(G@"JF$!`LHA``U*+$`LB^$;0?DA``.+C`$!BR']6],A%`FJC4$A
MBR$`#`M,_4+3BGD*JDP`"LJ,`0Y*BT$KB^P?0?F,`0.+:P$,BRS\6].,%0&J
M;D$LBXP!"PLK_4+3:7D)JDL!"<IK`0U*8D$BB^LC0?EK`0.+0@`+BXO]6]-K
M%0RJ34`KBVL!`@LB_$+307@!JB(!`<I"``Y*2D`JB^(G0?E"``.+2@$"BV+]
M6]-"%`NJ3D$BBT(`"@N*_4+33'D,JBH`#,I*`0U*24$IB^HK0?E*`0.+*0$*
MBTK\6]-*%0*J+4$JBTH!"0MI_4+3*WD+JHD!"\HI`0Y*(4$AB^DO0?DI`0.+
M(0`)BTG]6],I%0JJ+D`IBRD!`0M!_$+3(G@"JF$!`LHA``U*+$`LB^$S0?DA
M``.+C`$!BR']6],A%`FJC4$ABR$`#`M,_4+3BGD*JDP`"LJ,`0Y*BT$KB^PW
M0?F,`0.+:P$,BRS\6].,%0&J;D$LBXP!"PLK_4+3:7D)JDL!"<IK`0U*8D$B
MB^L[0?EK`0.+0@`+BXO]6]-K%0RJ34`KBVL!`@LB_$+307@!JB(!`<I"``Y*
M2D`JB^(_0?E"``.+2@$"BV+]6]-"%`NJ3T$BBT(`"@N*_4+33'D,JBH`#,I*
M`0U*A$`LBTE!*8OJ0T'Y2@$#BRD!"HM*_%O32A4"JDT!"0LN02J+:?U"TRMY
M"ZJ)`0O**0$/2B%!(8OI1T'Y*0$#BR$`"8NI_5O3*14-JB$`"0M)_$+3(GD"
MJFH!`LHI_%O3*14!JDH!#DHI`0J+(0`'"^I+0?E"``8+`@P`^4,!`XMC``2+
M(P$#"P,$`*FA_4+3(7@-JB$`!0L!"`#Y80$("P$0`/G```#P`.1'^>)/0?D!
M`$#Y0@`!ZP$`@-)```!4VO7_E_U[0*G_@PJ1P`-?UOU[OZD`$(#2_0,`D3/U
M_Y<?_`*I(F"$TJ+HK/("``#Y(G&5TA]X`+FB^;WR`@0`^<*?F])"%[/R`@@`
M^<*.BM)"!J+R`@P`^0(^G-)">KCR`A``^?U[P:C``U_6_7N\J?T#`)'S4P&I
M]`,`JO,#`:KU6P*I0'Q`D_4#`*KW8P.I@19`^2(,``L_``+KB0``5($:0/DA
M!`"1@1H`^8$:0/F6X@"1('1`BX*"`JF`>D"YH`,`-!<(@%+W`@!+_P(5:\#"
M((OWTI4:^'Y`DQ\`$^NB``!4`0`8BW\"`>O"``!4`'T@U&$"&(MI``!4'P`!
MZ_O__Q?B`QBJX0,3JHOU_Y>`>D"YX`(`"X!Z`+D?``%Q00(`5+4"%TMS`AB+
MX`,4JH?[_Y>7X@&1O_X`<0P"`%2B?D"3?P(6Z\D#`%3``@*+?P(`Z^/\_U3A
M`Q.JX`,6JG;U_Y>5>@"Y\U-!J?5;0JGW8T.I_7O$J,`#7]9_`A;K8`(!D8D!
M`%1_`A?K(_O_5&`&0*VU`@%1P`8`K6`&0:WS`P"JX`,4JL`&`:UH^_^7XO__
M%^+^_U3?`@#K]/__%\+\_U1@`@*+WP(`Z^+__Q?]>[RIX@^`$OT#`)'S4P&I
M]`,`JO,#`:KU6P*I->``D?<;`/D@%$#Y-BA`N3<P0+D`(`-3U@K`6@$$`!'W
M"L!:HLH@.*#"(8L_X`!QC0D`5`((@%)"``%+`0"`4D)\0).B]/^7X`,3JD7[
M_Y>_&@#Y``0`3Z`"`*V@"H`]X`,3JG=:#BD^^_^78`)`^0#\6-.``@`Y8`)`
M^0#\4-.`!@`Y8`)`^0#\2-.`"@`Y8`)`^8`.`#E@!D#Y`/Q8TX`2`#E@!D#Y
M`/Q0TX`6`#E@!D#Y`/Q(TX`:`#E@!D#Y@!X`.6`*0/D`_%C3@"(`.6`*0/D`
M_%#3@"8`.6`*0/D`_$C3@"H`.6`*0/F`+@`Y8`Y`^0#\6-.`,@`Y8`Y`^0#\
M4-.`-@`Y8`Y`^0#\2-.`.@`Y8`Y`^8`^`#E@$D#Y`/Q8TX!"`#E@$D#Y`/Q0
MTX!&`#E@$D#Y`/Q(TX!*`#E@$D#Y@$X`.>`#$ZKS4T&I]5M"J?<;0/G]>\2H
MZ/3_%P('@%)"``%+`0"`4D)\0)-7]/^7N___%_U[OZG]`P"1_7O!J,`#7]8N
M+@`E<R\E<P!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS
M.CI005(Z.D)/3U0`97AE`"]P<F]C+R5I+R5S`%!!4E]414U0`%!!4E]04D]'
M3D%-10`Z`"\`4$523#5,24(`4$523$Q)0@!015),-4]05`!015),24\`4$%2
M7TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@!005)?1$5"54<`
M4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"54<`4$%27T=,3T)!3%]435!$25(`
M4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@`Q
M`$Q$7TQ)0E)!4EE?4$%42`!365-414T`)3`R>`!P87(M`"5S)7,E<R5S`"5S
M.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@
M*&5R<FYO/25I*0H`)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N
M<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I
M;VXI"@!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M)74E<P`E
M<R5S=&5M<"TE=2TE=25S`!@`<&5R;``P`%!!4CHZ4&%C:V5R.CI615)324].
M`#$N,#4V`%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y`"5S.B!C
M<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL
M960@*&5R<FYO/25I*0H`+64`+2T`55-%4@!54T523D%-10!414U01$E2`%1-
M4``O=&UP`&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D
M0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C
M:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1&24Q%7V]F9G-E=%]S
M:7IE+"`D0T%#2$5?;6%R:V5R+"`D8V%C:&5?;F%M95]S:7IE*3L*0D5'24X@
M>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PHD1DE,15]O9F9S971?<VEZ
M92`](#0[("`@(R!P86-K*").(BD*)&-A8VAE7VUA<FME<B`](")<,$-!0TA%
M(CL*)&-A8VAE7VYA;65?<VEZ92`](#0P.PI]"G-U8B!F:6YD7W!A<E]M86=I
M8PI["FUY("@D9F@I(#T@0%\["FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T
M.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1F:#L*;7D@)'!O<R`]("1S:7IE
M("T@)'-I>F4@)2`D8VAU;FM?<VEZ93L@("`@("`C($Y/5$4Z("1P;W,@:7,@
M82!M=6QT:7!L92!O9B`D8VAU;FM?<VEZ90IW:&EL92`H)'!O<R`^/2`P*2![
M"G-E96L@)&9H+"`D<&]S+"`P.PIR96%D("1F:"P@)&)U9BP@)&-H=6YK7W-I
M>F4@*R!L96YG=&@H)%!!4E]-04=)0RD["FEF("@H;7D@)&D@/2!R:6YD97@H
M)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I('L*)'!O<R`K/2`D:3L*<F5T=7)N
M("1P;W,["GT*)'!O<R`M/2`D8VAU;FM?<VEZ93L*?0IR971U<FX@+3$["GT*
M;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A
M8VAE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I
M;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL
M93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE
M*"1P87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?
M=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_
M(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M
M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY
M("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8
M)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3
M549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE
M(#T@)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W
M:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF
M(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q
M"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO
M<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F
M:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T
M<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L
M96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ
M4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0[
M"F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!
M4E]$14)51WT["FUY("5S>7,@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@
M+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^
M("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L
M:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I
M+`HI.PI?<V5T7W!R;V=N86UE*"D["F]U=',H<7%;7"1P<F]G;F%M92`]("(D
M<')O9VYA;64B72D["E]S971?<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM0
M05)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB72D["FUY("@D<W1A<G1?<&]S
M+"`D9&%T85]P;W,I.PI-04=)0SH@>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]
M('-U8B![?3L*=6YL97-S("AO<&5N(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE
M*2!["F]U=',H<7%;0V%N)W0@<F5A9"!F<F]M(&9I;&4@(B1P<F]G;F%M92)=
M*3L@(",@9&]N)W0@=7-E("0A(&AE<F4@87,@:70@<F5Q=6ER97,@17)R;F\N
M<&T*;&%S="!-04=)0SL*?0IM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G
M:6,H*E]&2"D["FEF("@D;6%G:6-?<&]S(#P@,"D@>PIO=71S*'%Q6T-A;B=T
M(&9I;F0@;6%G:6,@<W1R:6YG("(D4$%27TU!1TE#(B!I;B!F:6QE("(D<')O
M9VYA;64B72D["FQA<W0@34%'24,["GT*;W5T<R@B1F]U;F0@4$%2(&UA9VEC
M(&%T('!O<VET:6]N("1M86=I8U]P;W,B*3L*<V5E:R!?1D@L("1M86=I8U]P
M;W,@+2`D1DE,15]O9F9S971?<VEZ92P@,#L*<F5A9"!?1D@L("1B=68L("1&
M24Q%7V]F9G-E=%]S:7IE.PIM>2`D;V9F<V5T(#T@=6YP86-K*").(BP@)&)U
M9BD["F]U=',H(D]F9G-E="!F<F]M('-T87)T(&]F($9)3$5S(&ES("1O9F9S
M970B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ
M92`M("1O9F9S970L(#`["B1D871A7W!O<R`]('1E;&P@7T9(.PIM>2`E<F5Q
M=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@("`@
M("`@("`@("`@("`C(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U
M9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D
M8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*
M;W5T<RAQ<5M5;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE(BXN+ETI.PIM>2`D
M8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D
M,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\
M*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D
M(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E
M>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D
M9FEL96YA;64@/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*
M)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE
M.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA
M;64["GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D
M969I;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?<V%V
M95]A<R@B)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)
M0CH@)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL
M;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D
M9G5L;&YA;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E
M860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S
M96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@
M(21M;V1U;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR
M971U<FX@=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I<F5?;&ES='LD;6]D
M=6QE?3L*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B
M.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ
M;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE
M(")#86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I
M.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*
M<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H
M(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL
M97T@/2`D9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA
M;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T
M=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F
M:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A
M9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD[
M"G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D
M>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL
M96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S
M<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@
M>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL
M96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE
M(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E
M7VQI<W1[)&9I;&5N86UE?3L*?0IU;FQE<W,@*"1B=68@97$@(E!+7#`P,UPP
M,#0B*2!["F]U=',H<7%;3F\@>FEP(&9O=6YD(&%F=&5R($9)3$4@<V5C=&EO
M;B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,@.PI]"B1S=&%R
M=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R
M="!O9B!Z:7`*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D
M;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]21553
M17T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L
M96TI"FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P
M=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L
M:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS
M("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D
M05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%2
M7T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@
M<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@
M>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L
M87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]
M"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H
M)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H
M)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2![
M"B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N
M9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q
M.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R
M(&]R(&1I92!Q<5M#86XG="!O<&5N(&QO9R!F:6QE("(D,B(Z("0A73L*?0IE
M;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H
M0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E
M("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$
M:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB
M4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N
M<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E
M<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E
M($1I9V5S=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z
M:7`["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D9F@L("<\.G)A=R<L
M("1P87(@;W(@9&EE('%Q6T-A;B=T(&9I;F0@<&%R(&9I;&4@(B1P87(B.B`D
M(5T["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI:
M:7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R
M*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@
M<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!A<B)=.PI]"FUY("5M971A7W!A<B`]
M(&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H
M)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A
M(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O
M;6<["GT*?3L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1P:"P@)SPZ
M<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@<F5A9"!P87(@9FEL92`B)'!A
M<B(Z("0A73L*;7D@)&)U9CL*<F5A9"`D<&@L("1B=68L(#0["F1I92!Q<5LB
M)'!A<B(@:7,@;F]T(&$@<&%R(&9I;&5=('5N;&5S<R`D8G5F(&5Q(")02UPP
M,#-<,#`T(CL*8VQO<V4@)'!H.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D
M9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I
M('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I
M+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B)&]U="(Z
M("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A
M9&5R.PII9B`H9&5F:6YE9"`D9&%T85]P;W,I('L*<F5A9"!?1D@L("1L;V%D
M97(L("1D871A7W!O<SL*?2!E;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*)&QO
M861E<B`](#Q?1D@^.PI]"FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D
M;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL
M=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<
M)&QO861E<BP@)#`I.PI]"FEF("@D;65T85]P87)[8VQE86Y]*2!["FUY("1P
M87)?8VQE86X@/2`B/3$B.PIM>2`D<&%S<U]P87)?8VQE86X@/2!U8R`B7U]P
M87-S7W!A<E]C;&5A;E]?(CL*)&QO861E<B`]?B!S>R@_/#TD>W!A<W-?<&%R
M7V-L96%N?2DH("LI?0I[)'!A<E]C;&5A;B`N("@B("(@>"`H;&5N9W1H*"0Q
M*2`M(&QE;F=T:"@D<&%R7V-L96%N*2DI?65G.PI]"B1F:"T^<')I;G0H)&QO
M861E<BD*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@;&]A9&5R('1O("(D;W5T
M(CH@)"%=.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!
M4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q
M=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*
M9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z
M.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG
M>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIS?"\K?"]\9RP@<WPO)'Q\(&9O<F5A
M8V@@0&EN8SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A
M9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?
M97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].R`@("`@("`@(",@6%A8
M(&QI8E]E>'0@=G,@9&QE>'0@/PIM>2`E=W)I='1E;CL*9F]R96%C:"!M>2`D
M:V5Y("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D9FEL92P@)&YA;64I.PII
M9B`H9&5F:6YE9"AM>2`D9F,@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1K
M97E]*2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D9F,I.PI]"F5L<V4@
M>PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1K97D@/7X@;7Q>7%$D
M9&ER7$4O*"XJ*21\:2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D,2D[
M"FQA<W0["GT*:68@*"1K97D@/7X@;7Q>+VQO861E<B];7B]=*R\H+BHI)'PI
M('L*:68@*&UY("1R968@/2`D36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@
M)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0II9B`H+68@(B1D:7(O)#$B
M*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]
M"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64["FYE>'0@:68@)'=R
M:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE
M(#U^("]<+EQ1)&QI8E]E>'1<120O:3L*;W5T<RAS<')I;G1F*'%Q6U!A8VMI
M;F<@1DE,12`B)7,B+BXN72P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z
M("1F:6QE*2D["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N
M=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;&]C86P@)"\@/2!U;F1E
M9CL*;W!E;B!M>2`D=&@L("<\.G)A=R<L("1F:6QE(&]R(&1I92!Q<5M#86XG
M="!R96%D("(D9FEL92(Z("0A73L*)&-O;G1E;G0@/2`\)'1H/CL*8VQO<V4@
M)'1H.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD8V]N=&5N="P@
M(CQE;6)E9&1E9#XO)&YA;64B*0II9B`A)$5.5GM005)?5D520D%424U](&%N
M9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0
M871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA
M;64I.PI]"B1F:"T^<')I;G0H(D9)3$4B+`IP86-K*"=.)RP@;&5N9W1H*"1N
M86UE*2`K(#DI+`IS<')I;G1F*"(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC
M;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M92DL"G!A8VLH)TXG+"!L96YG
M=&@H)&-O;G1E;G0I*2P*)&-O;G1E;G0I"F]R(&1I92!Q<5M%<G)O<B!W<FET
M:6YG(&5M8F5D9&5D($9)3$4@=&\@(B1O=70B.B`D(5T["F]U=',H<7%;5W)I
M='1E;B!A<R`B)&YA;64B72D["GT*?0II9B`H)'II<"D@>PHD>FEP+3YW<FET
M951O1FEL94AA;F1L92@D9F@I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TL*;W(@
M9&EE('%Q6T5R<F]R('=R:71I;F<@>FEP('!A<G0@;V8@(B1O=70B73L*?0HD
M8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@)&-A8VAE7VYA
M;65?<VEZ93L*:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T
M870H)&]U="DI6SE=*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I
M.PIO<&5N(&UY("1T:"P@(CPZ<F%W(BP@)&]U=#L*)&-T>"T^861D9FEL92@D
M=&@I.PIC;&]S92`D=&@["B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T
M.PI]"B1C86-H95]N86UE("X](")<,"(@>"`H)&-A8VAE7VYA;65?<VEZ92`M
M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1C86-H95]N86UE("X]("1C86-H95]M
M87)K97(["FUY("1O9F9S970@/2`D9F@M/G1E;&P@*R!L96YG=&@H)&-A8VAE
M7VYA;64I("T@;&5N9W1H*"1L;V%D97(I.PHD9F@M/G!R:6YT*"1C86-H95]N
M86UE+`IP86-K*"=.)RP@)&]F9G-E="DL"B1005)?34%'24,I"B8F("1F:"T^
M8VQO<V4*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@=')A:6QE<B!O9B`B)&]U
M="(Z("0A73L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL
M97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U
M:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E
M<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@
M)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*
M)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E
M;B@I(&9A:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M
M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@D>FEP+3YR
M96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z
M.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R
M8VAI=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ
M92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2
M.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*;W5T<R@B17AT<F%C=&EN
M9R!Z:7`N+BXB*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S
M:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E
M<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E
M8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN
M97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD
M0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG
M>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@
M/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.
M5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M
M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO
M=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A
M9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q
M6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B+BXN
M72D["B@D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D@
M/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@97AT
M<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N86UE(ET["F-H;6]D*#`U
M-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL
M97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@
M=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER
M(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P
M(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/
M1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B
M($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ
M0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z
M.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER
M92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S
M<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R
M97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A
M9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E
M('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER
M92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E
M<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E
M<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E
M(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE
M.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR
M97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q
M=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I
M<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!
M4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*
M979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T[
M"F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER
M92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE
M.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/
M.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T
M9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[
M4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A
M<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA
M<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-
M4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE
M<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM
M>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P
M=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R
M.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M
M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W
M=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D
M14Y6>U5315)]('Q\("=365-414TG.PI]"FUY("1S=&UP9&ER(#T@(B1P871H
M)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK
M9&ER("1S=&UP9&ER+"`P-S4U.PIM>2`D8V%C:&5?9&ER.PII9B`H)$5.5GM0
M05)?0TQ%04Y]*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["GT*96QS92![
M"F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A
M;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*:68@*"AM>2`D;6%G:6-?<&]S
M(#T@9FEN9%]P87)?;6%G:6,H)&9H*2D@/CT@,"D@>PIS965K("1F:"P@)&UA
M9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*"1C86-H95]M
M87)K97(I+"`P.PIM>2`D8G5F.PIR96%D("1F:"P@)&)U9BP@;&5N9W1H*"1C
M86-H95]M87)K97(I.PII9B`H)&)U9B!E<2`D8V%C:&5?;6%R:V5R*2!["G-E
M96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG
M=&@H)&-A8VAE7VUA<FME<BD*+2`D8V%C:&5?;F%M95]S:7IE+"`P.PIR96%D
M("1F:"P@)&)U9BP@)&-A8VAE7VYA;65?<VEZ93L*)&)U9B`]?B!S+UPP+R]G
M.PHD8V%C:&5?9&ER(#T@(F-A8VAE+21B=68B.PI]"GT*8VQO<V4@)&9H.PI]
M"FEF("@A)&-A8VAE7V1I<BD@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PHD
M14Y6>U!!4E]#3$5!3GT@/2`Q.PI]"B1S=&UP9&ER("X]("(D<WES>U]D96QI
M;7TD8V%C:&5?9&ER(CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["B1%3E9[4$%2
M7U1%35!](#T@)'-T;7!D:7(["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@
M)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*
M?0IS=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I
M(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE
M<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE
M+B0D(CL*;7D@)&9H.PHH;W!E;B`D9F@L("<^.G)A=R<L("1T96UP;F%M92D*
M)B8@*'!R:6YT("1F:"`D8V]N=&5N=',I"B8F("AC;&]S92`D9F@I"F]R(&1I
M92!Q<5M%<G)O<B!W<FET:6YG("(D=&5M<&YA;64B.B`D(5T["F-H;6]D("1M
M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP
M;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U
M<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN
M960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@
M/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@
M)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D
M14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R
M;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI("L@,2D[
M"GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE
M+"`D<WES>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L
M("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R
M;V=N86UE)'-Y<WM?97AE?2(I('L*)'!R;V=N86UE("X]("1S>7-[7V5X97T[
M"G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)'-Y<WMP
M871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.
M5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@
M/7X@<R]<421S>7-[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER
M)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(I+"!L87-T*0II9B`M
M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB.PHH*"1P
M<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I
M"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?
M9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!2
M3T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`\
M(#`I('L*)'!R;V=N86UE(#T@(BXD<WES>U]D96QI;7TD<')O9VYA;64B.PI]
M"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C
M=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T
M0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>
M*#\]7"Y<+C]<421S>7-[7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?9&5L:6U]+SL*
M)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN
M:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@
M>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#([
M"GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!2
M3T=.04U%("D@*2!["F1E;&5T92`D14Y6>R)005)?)%\B?3L*?0IF;W(@*'%W
M+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[(E!!4E\D7R)]
M(#T@)$5.5GLB4$%27T=,3T)!3%\D7R)](&EF(&5X:7-T<R`D14Y6>R)005)?
M1TQ/0D%,7R1?(GT["GT*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D
M14Y6>U!!4E]#3$5!3GT["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I
M970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E
M('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#
M;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ
M0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C
M:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD[
M"GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<
M)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q
M<5MP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z
M($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE("1P<F]G
M;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO
M7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?
M15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%
M4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2
M(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*`'!E<FQX<VDN8P````$;`SOT
M````'0```&B3__\,!0``6)7__PP!``"(E?__(`$``,B5__\T`0``*);__U@!
M``!<EO__>`$``!B7__^L`0``9)?__\P!``#XE___]`$``(B8__\8`@``U)G_
M_TP"``"@F___A`(``,R;__^8`@``')S__[P"``!0G?__[`(``%2=__\``P``
M.)___T0#``!HG___:`,``(2@__^@`P``K*'__]`#```$HO__]`,``"2B__\4
M!```V*+__TP$``#LJ/__K`0``,BJ___<!```+*O__S@%``#PN___7`4``$R\
M__]\!0``L+W__[0%````````$``````````!>E(`!'@>`1L,'P`0````&```
M`$24__\P`````````!`````L````8)3__SP`````````(````$````",E/__
M8`````!!#B"=!)X#0I,"5-[=TPX`````'````&0```#(E/__-`````!$#A"=
M`IX!1][=#@`````P````A````-R4__^\`````$$.0)T(G@=$DP:4!94$E@.7
M`I@!8PK>W=?8U=;3U`X`00L`'````+@```!DE?__3`````!##B"=!)X#3][=
M#@`````D````V````)"5__^4`````$$.0)T(G@="DP:4!465!%S>W=73U`X`
M(``````!``#\E?__D`````!!#K`!G1:>%423%%[>W=,.````,````"0!``!H
MEO__3`$```!!#M`!G1J>&4:3&)07E1:6%9<4F!,"2][=U]C5UM/4#@```#0`
M``!8`0``@)?__\P!````00Y@G0R>"T*3"I0)1Y4(E@>7!I@%F00":-[=V=?8
MU=;3U`X`````$````)`!```4F?__+``````````@````I`$``"R9__]0````
M`$$.()T$G@-"DP*4`4K>W=/4#@`L````R`$``%B9__\T`0```$(.T$!#G8H(
MGHD(0I.(")2'"$*5A@@"0]W>U=/4#@`0````^`$``%R:__\$`````````$``
M```,`@``3)K__^0!````0@[@(4&=G`2>FP1"DYH$E)D$1Y68!):7!)>6!)B5
M!)F4!)J3!`)LW=[9VM?8U=;3U`X`(````%`"``#LF___,`````!!#B"=!)X#
M0Y,"1][=TPX`````-````'0"``#XF___'`$```!"#K`@0YV&!)Z%!$*3A`24
M@P1T"MW>T]0.`$$+1PK=WM/4#@!""P`L````K`(``-R<__\H`0```$$.,)T&
MG@5$DP24`T.5`I8!>0K>W=76T]0.`$(+```@````W`(``-2=__]8`````$$.
M()T$G@-"DP)0"M[=TPX`00L<``````,```B>__\@`````$$.$)T"G@%&WMT.
M`````#0````@`P``")[__[0`````00XPG0:>!4*5`I8!0Y,$E`-,"M[=U=;3
MU`X`00M9WMW5UM/4#@``7````%@#``"$GO__%`8```!"#I"#`D*=LB">L2!"
MD[`@E*\@1)6N():M($67K""8JR"9JB":J2";J"!K"MW>V]G:U]C5UM/4#@!!
M"P)G"MW>V]G:U]C5UM/4#@!!"P``+````+@#```XI/__W`$```!!#D"=")X'
M0I,&E`5%E026`Y<"`F[>W=?5UM/4#@``+````.@#``#DI?__9`````!!#B"=
M!)X#0I,"E`%2"M[=T]0.`$$+0M[=T]0.````*````!@$``!4CO__J`$```!!
M#E"="IX)0I,(E`=$E08"7PK>W=73U`X`00L@````1`0``.RE___$$````$$.
MH`5%G52>4P,J!-W>#@`````<````:`0``(RV__]<`````$$.$)T"G@%5WMT.
M`````#0```"(!```R+;__V0!````00Y`G0B>!T*3!I0%1)4$E@-"EP*8`7H*
MWMW7V-76T]0.`$$+````,````,`$``#TM___E`$```!!#D"=")X'0Y,&E`5#
ME026`T*7`@)5"M[=U]76T]0.`$$+````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"`@````````P!\````````!`````````/4"````````
M`0```````````P````````\`````````3@0````````,`````````'@9````
M````#0`````````\20```````!D`````````F/L!```````;``````````@`
M````````&@````````"@^P$``````!P`````````"`````````#U_O]O````
M`"`"````````!0````````#(#`````````8`````````"`,````````*````
M`````&P$````````"P`````````8`````````!4````````````````````#
M`````````(C]`0```````@````````"(!0```````!0`````````!P``````
M```7`````````/`3````````!P`````````X$0````````@`````````N`(`
M```````)`````````!@`````````&````````````````````/O__V\`````
M`0``"`````#Y__]O`````!``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````"0&0``````
M`)`9````````D!D```````"0&0```````)`9````````D!D```````"0&0``
M`````)`9````````D!D```````"0&0```````)`9````````D!D```````"0
M&0```````)`9````````D!D```````"0&0```````)`9````````D!D`````
M``"0&0```````)`9````````D!D```````"0&0```````)`9````````D!D`
M``````"0&0```````)`9````````D!D```````"0&0```````)`9````````
MD!D```````"0&0```````)`9````````D!D```````"0&0```````)`9````
M````D!D```````"0&0```````)`9````````D!D```````"0&0```````)`9
M````````D!D```````"0&0```````)`9````````D!D```````"0&0``````
M`)`9````````D!D```````"0&0```````)`9````````D!D```````"0&0``
M`````)`9````````D!D```````"0&0```````)`9````````D!D```````"0
M&0```````)`9````````J/L!``````!@'0``````````````````````````
M```\20````````````````````````````!X&0``````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````@``````_____P````#R2P```````$U)````
M```````````````N2@```````"=*````````YDL```````!$2@```````.Y+
M``````````````````#82P```````-U+``````````````````#W2P``````
M`$=#0SH@*$%L<&EN92`Q,BXR+C%?9VET,C`R,C`Y,C0M<C0I(#$R+C(N,2`R
M,#(R,#DR-```+G-H<W1R=&%B`"YI;G1E<G``+F=N=2YH87-H`"YD>6YS>6T`
M+F1Y;G-T<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YI;FET`"YT97AT`"YF:6YI
M`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+FEN:71?87)R87D`
M+F9I;FE?87)R87D`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT
M````````````````````````````````````````````````````````````
M````````````````````````````````````"P````$````"```````````"
M``````````(````````:`````````````````````0``````````````````
M`!,```#V__]O`@`````````@`@```````"`"````````Z``````````#````
M``````@````````````````````=````"P````(`````````"`,````````(
M`P```````,`)````````!`````,````(`````````!@`````````)0````,`
M```"`````````,@,````````R`P```````!L!````````````````````0``
M`````````````````"T````$`````@`````````X$0```````#@1````````
MN`(````````#``````````@`````````&``````````W````!````$(`````
M````\!,```````#P$P```````(@%`````````P```!$````(`````````!@`
M````````00````$````&`````````'@9````````>!D````````0````````
M````````````!````````````````````#P````!````!@````````"0&0``
M`````)`9````````T`,``````````````````!````````````````````!'
M`````0````8`````````8!T```````!@'0```````-PK````````````````
M```0````````````````````30````$````&`````````#Q)````````/$D`
M```````0````````````````````!````````````````````%,````!````
M`@````````!,20```````$Q)````````JD````````````````````$`````
M``````````````!;`````0````(`````````^(D```````#XB0```````/0`
M```````````````````$````````````````````:0````$````"````````
M`/"*````````\(H```````#T!```````````````````"```````````````
M`````',````.`````P````````"8^P$``````)C[````````"```````````
M``````````@`````````"`````````!_````#P````,`````````H/L!````
M``"@^P````````@````````````````````(``````````@`````````BP``
M``8````#`````````*C[`0``````J/L```````#@`0````````0`````````
M"``````````0`````````)0````!`````P````````"(_0$``````(C]````
M````>`(```````````````````@`````````"`````````"9`````0````,`
M```````````"``````````$``````'@````````````````````(````````
M````````````GP````@````#`````````'@``@``````>``!``````!8````
M````````````````"````````````````````*0````!````,```````````
M`````````'@``0``````-`````````````````````$``````````0``````
M```!`````P````````````````````````"L``$``````*T`````````````
5```````!````````````````````
